@@ -63,14 +63,17 @@ def send_notifications(email, sender, email_configuration):
     # The full path to the file that will be attached to the email.
     ATTACHMENT = LOG_PATH
     cover = email_configuration.get('Banner')
+    logger.info(cover)
     logo = email_configuration.get('Logo')
+    logger.info(logo)
     paragraph = email_configuration.get('Email_Content')
+    logger.info(paragraph)
     # # The HTML body of the email.
     file_name = email_configuration.get('HTML_File')
     # email_html = open(file_name)
-    BODY_HTML = open('/HTML_files/' + file_name).read().format(cover=cover,
-                                                           logo=logo,
-                                                           paragraph=paragraph)
+    BODY_HTML = open('\media' + file_name).read().format(cover=cover,
+                                                         logo=logo,
+                                                         paragraph=paragraph)
     # Define the attachment part and encode it using MIMEApplication.
     att = MIMEApplication(open(ATTACHMENT, 'rb').read())
 
